'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.add = add;
exports.updateByIndex = updateByIndex;
exports.updateWhere = updateWhere;
exports.removeAtIndex = removeAtIndex;
exports.removeEqualTo = removeEqualTo;
exports.clear = clear;

var _objects = require('./objects');

/**
 * Add item to array
 */
function add(state, action) {
  var payload = action.payload;


  if (!payload) throw new Error('No payload received by arrayPush! Did your action include a payload?');

  return state.concat(payload);
}

/**
 * Update array value by index
 */
function updateByIndex(state, action) {
  var payload = action.payload;
  var index = payload.index;
  var item = payload.item;


  return state.slice(0, index).concat(item).concat(state.slice(index + 1));
}

/**
 * Update objects in array where equal to
 *
 * TODO: support arrays in where check, i.e. update where ['foo', 'bar']
 */
function updateWhere(state, action) {
  var payload = action.payload;
  var updates = payload.updates;
  var where = payload.where;


  if (!where || !updates) throw new Error('"where" and "updates" keys must be present in updateWhere.');

  var copy = state.concat();

  for (var i = 0; i < copy.length; i++) {
    var item = copy[i];
    if ((0, _objects.containsMatches)(item, where)) {
      copy[i] = (0, _objects.update)(item, { payload: updates });
    }
  }

  return copy;
}

/**
 * Remove an array item at a specific index
 */
function removeAtIndex(state, action) {
  var payload = action.payload;

  var index = payload;

  return state.slice(0, index).concat(state.slice(index + 1));
}

/**
 * Remove items from array where value is equal to
 */
function removeEqualTo(state, action) {
  var payload = action.payload;


  return state.filter(function (item) {
    return item != payload;
  });
}

/**
 * Return a blank array
 */
function clear(state, action) {
  return [];
}