'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

exports.update = update;
exports.updateWhere = updateWhere;
exports.remove = remove;
exports.containsMatches = containsMatches;
/**
 * Iterate over an object and replace values of keys present in payload
 */
function update(state, action) {
  var payload = action.payload;


  if ((typeof payload === 'undefined' ? 'undefined' : _typeof(payload)) != 'object') throw new Error('payload must be an object!');

  var updated = Object.assign({}, state, payload);
  return updated;
}

/**
 * Iterate over object and make updates where matches
 */
function updateWhere(state, action) {
  var payload = action.payload;
  var where = payload.where;
  var updates = payload.updates;


  if (!where || !updates) throw new Error('"where" and "updates" keys must be present in updateWhere.');

  var copy = Object.assign({}, state);
  for (var key in copy) {
    var item = copy[key];

    if (containsMatches(item, where)) {
      copy[key] = update(item, { payload: updates });
    }
  }

  return copy;
}

/**
 * Remove a specific key
 */
function remove(state, action) {
  var payload = action.payload;


  var err = function err() {
    throw new Error('Key must be a string!');
  };

  var type = typeof payload === 'undefined' ? 'undefined' : _typeof(payload);

  var isArray = Array.isArray(payload);
  if (type != 'string' && !isArray) {
    err();
  }

  var omit = {};
  if (isArray) {
    for (var i = 0; i < payload.length; i++) {
      omit[payload[i]] = true;
    }
  } else {
    omit[payload] = true;
  }

  var copy = {};
  for (var key in state) {
    if (!omit[key]) copy[key] = state[key];
  }

  return copy;
}

/**
 * Check if an object matches some arguments, i.e:
 *
 * does {foo: 'bar', id: 1} match {id: 1}
 */
function containsMatches(object, where) {
  for (var key in where) {
    if (object[key] != where[key]) return false;
  }

  return true;
}